@@ -34,11 +34,11 @@ def fixedwidth(field, name=None, pt=6, width=16, maxlen=64, pretty=False):
         if val.startswith("u'") or val.startswith('u"'):
             val = val[2:-1]
         shortval = val.replace(",", ",\n")
-        shortval = shortval.replace("\n", "<br />")
+        shortval = shortval.replace("\n", "|br/|")
 
         if len(shortval) > maxlen:
             shortval = shortval[:maxlen] + "..."
-        return """<span title="%s", style="font-size: %spt;
-                               font-family: Menlo, Courier;
-                  ">%s</span>""" % (escape(val[:255]), pt, escape(shortval), )
+        return """<span title="%s", style="font-size: %spt;\
+                        font-family: Menlo, Courier; ">%s</span>""" % (
+            escape(val[:255]), pt, escape(shortval)).replace("|br/|", "<br/>")
     return f
