@@ -1,17 +1,19 @@
 """celery.backends.cache"""
+from __future__ import absolute_import
+
 from datetime import timedelta
 
 import django
 from django.utils.encoding import smart_str
 from django.core.cache import cache, get_cache
 
-from celery.app import default_app
+from celery import current_app
 from celery.utils.timeutils import timedelta_seconds
 from celery.backends.base import KeyValueStoreBackend
 
 # CELERY_CACHE_BACKEND overrides the django-global(tm) backend settings.
-if default_app.conf.CELERY_CACHE_BACKEND:
-    cache = get_cache(default_app.conf.CELERY_CACHE_BACKEND)  # noqa
+if current_app.conf.CELERY_CACHE_BACKEND:
+    cache = get_cache(current_app.conf.CELERY_CACHE_BACKEND)  # noqa
 
 
 class DjangoMemcacheWrapper(object):
@@ -51,7 +53,7 @@ class CacheBackend(KeyValueStoreBackend):
     def __init__(self, *args, **kwargs):
         super(CacheBackend, self).__init__(self, *args, **kwargs)
         expires = kwargs.get("expires",
-                             default_app.conf.CELERY_TASK_RESULT_EXPIRES)
+                             current_app.conf.CELERY_TASK_RESULT_EXPIRES)
         if isinstance(expires, timedelta):
             expires = int(timedelta_seconds(expires))
         self.expires = expires
