@@ -15,7 +15,9 @@ command = camqadm.AMQPAdminCommand(app=app)
 
 class Command(CeleryCommand):
     """Run the celery daemon."""
-    option_list = CeleryCommand.option_list + command.get_options()
+    options = (CeleryCommand.options
+              + command.get_options()
+              + command.preload_options)
     help = 'Celery AMQP Administration Tool using the AMQP API.'
 
     def handle(self, *args, **options):
