@@ -15,7 +15,9 @@ ev = celeryev.EvCommand(app=app)
 
 class Command(CeleryCommand):
     """Run the celery curses event viewer."""
-    option_list = CeleryCommand.option_list + ev.get_options()
+    options = (CeleryCommand.options
+             + ev.get_options()
+             + ev.preload_options)
     help = 'Takes snapshots of the clusters state to the database.'
 
     def handle(self, *args, **options):
