@@ -17,7 +17,9 @@ class Command(CeleryCommand):
     """Run the celery daemon."""
     help = 'Runs a Celery worker node.'
     requires_model_validation = True
-    option_list = CeleryCommand.option_list + worker.get_options()
+    options = (CeleryCommand.options
+             + worker.get_options()
+             + worker.preload_options)
 
     def handle(self, *args, **options):
         worker.run(*args, **options)
