@@ -17,7 +17,7 @@ class Command(CeleryCommand):
     """Run the celery daemon."""
     help = 'Runs a detached Celery worker node.'
     requires_model_validation = True
-    option_list = celeryd_detach.OPTION_LIST
+    options = celeryd_detach.OPTION_LIST
 
     def run_from_argv(self, argv):
 
