@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+
 import sys
 
 from datetime import timedelta
@@ -97,10 +99,10 @@ class test_CacheBackend(unittest.TestCase):
 class test_custom_CacheBackend(unittest.TestCase):
 
     def test_custom_cache_backend(self):
-        from celery.app import default_app
-        prev_backend = default_app.conf.CELERY_CACHE_BACKEND
+        from celery import current_app
+        prev_backend = current_app.conf.CELERY_CACHE_BACKEND
         prev_module = sys.modules["djcelery.backends.cache"]
-        default_app.conf.CELERY_CACHE_BACKEND = "dummy://"
+        current_app.conf.CELERY_CACHE_BACKEND = "dummy://"
         sys.modules.pop("djcelery.backends.cache")
         try:
             from djcelery.backends.cache import cache
@@ -109,7 +111,7 @@ class test_custom_CacheBackend(unittest.TestCase):
                               "django.core.cache.backends.dummy")
             self.assertIsNot(cache, django_cache)
         finally:
-            default_app.conf.CELERY_CACHE_BACKEND = prev_backend
+            current_app.conf.CELERY_CACHE_BACKEND = prev_backend
             sys.modules["djcelery.backends.cache"] = prev_module
 
 
@@ -135,7 +137,6 @@ class test_MemcacheWrapper(unittest.TestCase):
 
             self.assertEqual(cache.get(key, default=default), default)
             cache.set(key, val)
-            print("VAL: %r" % (cache.get(key, default=default), ))
             self.assertEqual(cache.get(key, default=default),
                               val)
         finally:
