@@ -10,6 +10,7 @@ from celery.utils import gen_unique_id
 
 from djcelery import snapshot
 from djcelery import models
+from djcelery.utils import now, make_aware
 from djcelery.tests.utils import unittest
 
 _next_id = count(0).next
@@ -45,7 +46,7 @@ class test_Camera(unittest.TestCase):
         for t in t1, t2, t3:
             worker.on_heartbeat(timestamp=t)
         self.assertEqual(self.cam.get_heartbeat(worker),
-                        datetime.fromtimestamp(t3))
+                        make_aware(datetime.fromtimestamp(t3)))
 
     def test_handle_worker(self):
         worker = Worker(hostname="fuzzie")
@@ -71,7 +72,7 @@ class test_Camera(unittest.TestCase):
         self.assertEqual(mt.name, task.name)
         self.assertTrue(unicode(mt))
         self.assertTrue(repr(mt))
-        mt.eta = datetime.now()
+        mt.eta = now()
         self.assertIn("eta", unicode(mt))
         self.assertIn(mt, models.TaskState.objects.active())
 
